AsyncError<T> class final

Error state

Inheritance

Constructors

AsyncError(Object error, [StackTrace? stackTrace])

Properties

error Object
final
errorOrNull Object?
Gets the error if in error state, null otherwise
no setterinherited
hasData bool
Checks if the state has data
no setterinherited
hasError bool
Checks if the state has an error
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
Checks if the state is loading
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
valueOrNull → T?
Gets the value if in data state, null otherwise
no setterinherited

Methods

map<R>({required R loading(), required R error(Object error, StackTrace? stackTrace), required R data(T data)}) → R
Pattern matching method similar to Riverpod's AsyncValue.map
inherited
mapOrNull<R>({R loading()?, R error(Object error, StackTrace? stackTrace)?, R data(T data)?}) → R?
Pattern matching method that doesn't require all cases
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited