UserService class

Service class that handles user data fetching and state management.

Inheritance

Constructors

UserService({UserRepository? repository})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value AsyncValue<User>
The current user state
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
getCurrentUser() Future<User>
Fetches the current user (using token 0 as placeholder). In a real app, you would get the token from the local storage.
getUserByToken(int token) Future<User>
Fetches a user by token. In a real app, you would get the token from the local storage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() Future<void>
Reloads the user data
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited