BaseSpacing class
Constructors
- BaseSpacing({SizePrimitiveTokens? sizeTokens})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeTokens → SizePrimitiveTokens
-
final
- spacing → SpacingTokens
-
no setter
-
spacingEntries
→ Iterable<
MapEntry< String, double> > -
no setter
-
spacingMap
→ Map<
String, double> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited