BaseTextStyles class

Constructors

BaseTextStyles()

Properties

baseFontFamily BaseFontFamily
final
baseFontSize BaseFontSize
final
baseFontWeight BaseFontWeight
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typography TypographyTokens
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited