ResponsiveUtil class

Constructors

ResponsiveUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isLargeScreen(BuildContext context) bool
isMobileScreen(BuildContext context) bool
isTabletScreen(BuildContext context) bool
screenWidth(BuildContext context) double