SelectionChip class
A selection chip component that follows the TFN design system specification.
The selection chip displays a label with an optional leading icon (e.g. flag) and a trailing close button. It supports enabled, selected, and disabled states.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SelectionChip
Constructors
-
SelectionChip({Key? key, required String label, bool isSelected = false, bool enabled = true, Widget? leadingIcon, ValueChanged<
bool> ? onSelected, VoidCallback? onDeleted}) -
const
Properties
- enabled → bool
-
Whether the chip is disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected → bool
-
Whether the chip is currently selected.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
The text label displayed in the chip.
final
- leadingIcon → Widget?
-
Optional leading icon widget (e.g. a flag or custom icon).
final
- onDeleted → VoidCallback?
-
Callback when the close/delete button is pressed.
final
-
onSelected
→ ValueChanged<
bool> ? -
Callback when the chip selection changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited