TextInput class
Themed text form field with label, placeholder, helper/error text, and optional leading/trailing icons.
Base input used across the design system; supports validation, required, read-only, and disabled states.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TextInput
Constructors
-
TextInput({Key? key, required String label, required String placeholder, String? initialValue, bool enabled = true, bool readOnly = false, bool obscureText = false, bool autocorrect = true, bool enableSuggestions = true, bool enableInteractiveSelection = true, TextEditingController? controller, FormFieldValidator<
String> ? validator, FormFieldSetter<String> ? onSaved, AutovalidateMode autovalidateMode = AutovalidateMode.disabled, TextInputType keyboardType = TextInputType.text, TextInputAction textInputAction = TextInputAction.next, InputDecoration? decoration, dynamic onChanged(String)?, VoidCallback? onTap, String? helperText, String? errorText, Widget? leadingIcon, Widget? trailingIcon, Widget? trailingIcon2, bool required = false}) -
const
Properties
- autocorrect → bool
-
final
- autovalidateMode → AutovalidateMode
-
final
- controller → TextEditingController?
-
final
- decoration → InputDecoration?
-
final
- enabled → bool
-
final
- enableInteractiveSelection → bool
-
final
- enableSuggestions → bool
-
final
- errorText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- initialValue → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType
-
final
- label → String
-
final
- leadingIcon → Widget?
-
final
- obscureText → bool
-
final
- onChanged → dynamic Function(String)?
-
final
-
onSaved
→ FormFieldSetter<
String> ? -
final
- onTap → VoidCallback?
-
final
- placeholder → String
-
final
- readOnly → bool
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textInputAction → TextInputAction
-
final
- trailingIcon → Widget?
-
final
- trailingIcon2 → Widget?
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited